@@ -42,7 +42,7 @@ x_o_diff_dict = {}
 class RelationExtractionVisualizer:
     
     def __init__(self):
-        with open('label_colors/rel_color.json'), 'r', encoding='utf-8') as f_:
+        with open('label_colors/rel_color.json', 'r', encoding='utf-8') as f_:
             self.color_dict = json.load(f_)
         with open('label_colors/entity_color.json', 'r', encoding='utf-8') as f_:
             self.entity_color_dict = json.load(f_)
